@@ -1,5 +1,6 @@
 use crate::event::{ClickState, EventPayload, EventProxy, RioEvent, RioEventType};
 use crate::ime::Preedit;
+use crate::renderer::utils::update_colors_based_on_theme;
 use crate::router::{routes::RoutePath, Router};
 use crate::scheduler::{Scheduler, TimerId, Topic};
 use crate::screen::touch::on_touch;
@@ -115,6 +116,8 @@ impl ApplicationHandler<EventPayload> for Application<'_> {
             return;
         }
 
+        update_colors_based_on_theme(&mut self.config, event_loop.system_theme());
+
         self.router.create_window(
             event_loop,
             self.event_proxy.clone(),
@@ -226,8 +229,8 @@ impl ApplicationHandler<EventPayload> for Application<'_> {
                         }
                     }
 
-                    route.window.configure_window(&self.config);
                     route.update_config(&self.config, &self.router.font_library);
+                    route.window.configure_window(&self.config);
 
                     if let Some(error) = &config_error {
                         route.report_error(&error.to_owned().into());
@@ -275,6 +278,13 @@ impl ApplicationHandler<EventPayload> for Application<'_> {
                     }
                 }
             }
+            RioEventType::Rio(RioEvent::CursorBlinkingChangeOnRoute(route_id)) => {
+                if let Some(route) = self.router.routes.get_mut(&window_id) {
+                    if route_id == route.window.screen.ctx().current_route() {
+                        route.request_redraw();
+                    }
+                }
+            }
             RioEventType::Rio(RioEvent::PrepareRender(millis)) => {
                 let timer_id = TimerId::new(Topic::Render, window_id);
                 let event =
@@ -305,6 +315,22 @@ impl ApplicationHandler<EventPayload> for Application<'_> {
                     );
                 }
             }
+            RioEventType::Rio(RioEvent::BlinkCursor(millis, route_id)) => {
+                let timer_id = TimerId::new(Topic::CursorBlinking, window_id);
+                let event = EventPayload::new(
+                    RioEventType::Rio(RioEvent::CursorBlinkingChangeOnRoute(route_id)),
+                    window_id,
+                );
+
+                if !self.scheduler.scheduled(timer_id) {
+                    self.scheduler.schedule(
+                        event,
+                        Duration::from_millis(millis),
+                        false,
+                        timer_id,
+                    );
+                }
+            }
             RioEventType::Rio(RioEvent::Title(title)) => {
                 if let Some(route) = self.router.routes.get_mut(&window_id) {
                     route.set_window_title(&title);
@@ -316,7 +342,6 @@ impl ApplicationHandler<EventPayload> for Application<'_> {
                     route.set_window_subtitle(&subtitle);
                 }
             }
-            RioEventType::BlinkCursor | RioEventType::BlinkCursorTimeout => {}
             RioEventType::Rio(RioEvent::MouseCursorDirty) => {
                 if let Some(route) = self.router.routes.get_mut(&window_id) {
                     route.window.screen.reset_mouse();
@@ -982,11 +1007,12 @@ impl ApplicationHandler<EventPayload> for Application<'_> {
             }
 
             WindowEvent::ThemeChanged(new_theme) => {
-                route.window.screen.update_config(
-                    &self.config,
-                    Some(new_theme),
-                    &self.router.font_library,
-                );
+                update_colors_based_on_theme(&mut self.config, Some(new_theme));
+                route
+                    .window
+                    .screen
+                    .update_config(&self.config, &self.router.font_library);
+                route.window.configure_window(&self.config);
             }
 
             WindowEvent::DroppedFile(path) => {
