@@ -61,9 +61,7 @@ impl Route<'_> {
         config: &RioConfig,
         db: &rio_backend::sugarloaf::font::FontLibrary,
     ) {
-        self.window
-            .screen
-            .update_config(config, self.window.winit_window.theme(), db);
+        self.window.screen.update_config(config, db);
     }
 
     #[inline]
@@ -356,7 +354,6 @@ impl<'a> RouteWindow<'a> {
             raw_window_handle: winit_window.window_handle().unwrap().into(),
             raw_display_handle: winit_window.display_handle().unwrap().into(),
             window_id: winit_window.id(),
-            theme: winit_window.theme(),
         };
 
         let screen = Screen::new(
