@@ -93,7 +93,6 @@ pub struct ScreenWindowProperties {
     pub raw_window_handle: RawWindowHandle,
     pub raw_display_handle: RawDisplayHandle,
     pub window_id: rio_window::window::WindowId,
-    pub theme: Option<rio_window::window::Theme>,
 }
 
 impl Screen<'_> {
@@ -110,7 +109,6 @@ impl Screen<'_> {
         let raw_window_handle = window_properties.raw_window_handle;
         let raw_display_handle = window_properties.raw_display_handle;
         let window_id = window_properties.window_id;
-        let theme = window_properties.theme;
 
         let padding_y_top =
             padding_top_from_config(&config.navigation, config.padding_y[0], 1);
@@ -177,7 +175,7 @@ impl Screen<'_> {
             }
         };
 
-        let renderer = Renderer::new(config, theme, font_library);
+        let renderer = Renderer::new(config, font_library);
 
         let bindings = crate::bindings::default_key_bindings(
             config.bindings.keys.to_owned(),
@@ -305,7 +303,6 @@ impl Screen<'_> {
     pub fn update_config(
         &mut self,
         config: &rio_backend::config::Config,
-        current_theme: Option<rio_window::window::Theme>,
         font_library: &rio_backend::sugarloaf::font::FontLibrary,
     ) {
         let num_tabs = self.ctx().len();
@@ -328,7 +325,7 @@ impl Screen<'_> {
         );
 
         self.sugarloaf.layout_mut().update();
-        self.renderer = Renderer::new(config, current_theme, font_library);
+        self.renderer = Renderer::new(config, font_library);
 
         for context in self.ctx().contexts() {
             let mut terminal = context.terminal.lock();
@@ -1924,7 +1921,6 @@ impl Screen<'_> {
             None
         };
 
-        // let start = std::time::Instant::now();
         let (rows, cursor, display_offset, has_blinking_enabled) = {
             let terminal = self.context_manager.current().terminal.lock();
             let data = (
@@ -1937,10 +1933,6 @@ impl Screen<'_> {
             data
         };
         self.renderer.set_ime(self.ime.preedit());
-        // let duration = start.elapsed();
-        // println!("Total terminal with set_ime info is: {:?}", duration);
-
-        // let start = std::time::Instant::now();
         self.renderer.prepare_term(
             &rows,
             cursor,
@@ -1951,20 +1943,14 @@ impl Screen<'_> {
             &mut search_hints,
             &self.search_state.focused_match,
         );
-
-        // let duration = start.elapsed();
-        // println!("Total prepare_term is: {:?}", duration);
-
-        // let start = std::time::Instant::now();
         self.sugarloaf.render();
-        // let duration = start.elapsed();
-        // println!("Total render is: {:?}", duration);
 
         // In this case the configuration of blinking cursor is enabled
         // and the terminal also have instructions of blinking enabled
         // TODO: enable blinking for selection after adding debounce (https://github.com/raphamorim/rio/issues/437)
         if self.renderer.has_blinking_enabled() && self.selection_is_empty() {
-            self.context_manager.schedule_render_on_route(800);
+            self.context_manager
+                .blink_cursor(self.renderer.config_blinking_interval);
         }
 
         // let duration = start_total.elapsed();
