@@ -10,6 +10,11 @@ pub fn default_line_height() -> f32 {
     1.0
 }
 
+#[inline]
+pub fn default_cursor_interval() -> u64 {
+    800
+}
+
 #[inline]
 pub fn default_max_fps() -> u64 {
     if cfg!(target_os = "macos") {
@@ -132,19 +137,6 @@ pub fn default_config_file_content() -> String {
 # Example:
 # ignore-selection-foreground-color = false
 
-# Cursor
-#
-# [cursor]
-#
-# Default cursor shape is 'block'
-# Other available options are: 'underline', 'beam' or 'hidden'
-#
-# shape = 'block'
-#
-# Whether the cursor blinks. The default is true
-#
-# blinking = false
-
 # Theme
 #
 # It makes Rio look for the specified theme in the themes folder
@@ -214,6 +206,20 @@ pub fn default_config_file_content() -> String {
 #
 # confirm-before-quit = false
 
+# Cursor
+#
+# shape - Default cursor shape is 'block'
+# Other available options are: 'underline', 'beam' or 'hidden'
+#
+# blinking - Whether the cursor blinks. The default is true
+#
+# blinking-interval - Cursor update on milliseconds interval
+#
+# [cursor]
+# shape = 'block'
+# blinking = false
+# blinking-interval = 800 
+
 # Editor
 #
 # Default editor is "vi".
